import sys
import time

from .common import execute


def main():
    argv = sys.argv[1:]
    begin = time.monotonic()
    execute(" ".join(argv))
    end = time.monotonic()
    print(f"Exited in {end - begin}s")
    sys.exit()


if __name__ == '__main__':
    main()



import os
import sys


def main():
    argv = sys.argv[1:]
    if len(argv) != 3:
        sys.exit("ArgvError: ucp <bufsize> <src_path> <dst_path>")
    if not argv[0].isdigit():
        sys.exit("ArgvError: bugsize must be int")
    bufsize = int(argv[0])
    if bufsize < 1:
        sys.exit("ArgvError: bugsize must be greater than 0")
    bufsize = max(int(argv[0]), 2)
    src_path = argv[1]
    dst_path = argv[2]
    if dst_path.endswith(os.sep):
        dst_path += src_path.split(os.sep)[-1]
    with open(src_path, "rb", buffering=bufsize) as src:
        with open(dst_path, "wb+", buffering=bufsize) as dst:
            while True:
                chunk = src.read(bufsize)  
                if not chunk:
                    break
                dst.write(chunk)
    sys.exit()


if __name__ == '__main__':
    main()



import sys
import signal
import time
from functools import partial


def handler(counters, signum, *args):
    print(f"C1 received signal {signum}")
    counters["i"] += 1
    if counters["i"] == 10:
        sys.exit()


def main():
    counters = {"i": 0}
    if sys.platform.startswith("linux"):
        signal.signal(signal.SIGALRM, partial(handler, counters))
    else:
        signal.signal(signal.SIGBREAK, partial(handler, counters))
    while True:
        pass


if __name__ == '__main__':
    main()



import sys

from .common import execute


def main():
    argv = sys.argv[1:]
    if argv:
        sys.exit("ArgvError: procmax takes no argument")
    if sys.platform.startswith("linux"):
        execute("ulimit -p")
    else:
        print("unlimited")
    sys.exit()


if __name__ == '__main__':
    main()



import subprocess


def execute(cmd):
    popen = subprocess.Popen(cmd, stdout=subprocess.PIPE, text=True, shell=True)
    for stdout_line in iter(popen.stdout.readline, ""):
        print(stdout_line, end="") 
    popen.stdout.close()
    return popen.wait()




import sys
from os import path

from setuptools import setup, find_packages

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


setup(
    name="dumbtils",
    version="0.1.1",
    author="Paaksing",
    author_email="paaksingtech@gmail.com",
    url="https://github.com/paaksing/dumbtils",
    description="Dumb Utilities.",
    long_description=long_description,
    long_description_content_type='text/markdown',
    keywords=["utils"],
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
    ],
    license="MIT",
    packages=find_packages(exclude=("test")),
    zip_safe=True,
    install_requires=[],
    include_package_data=True,
    entry_points={
        'console_scripts': [
            'procmax=dumbtils.procmax:main',
            'timeprog=dumbtils.timeprog:main',
            'ucp=dumbtils.ucp:main',
            'tictoc=dumbtils.tictoc:main',
        ]
    }
)



import os
import sys
import time
import signal
import subprocess

from . import _c1, _c2


def main():
    argv = sys.argv[1:]
    if argv:
        sys.exit("ArgvError: tictoc takes no argument")
    if sys.platform.startswith("win32"):
        python_cmd = "py"
        c1 = subprocess.Popen([python_cmd, '-u', _c1.__file__], stdout=subprocess.PIPE, shell=True, creationflags=subprocess.CREATE_NEW_PROCESS_GROUP)
    else:
        python_cmd = "python3"
        c1 = subprocess.Popen([python_cmd, '-u', _c1.__file__], stdout=subprocess.PIPE, shell=True)
    c2 = subprocess.Popen([python_cmd, '-u', _c2.__file__], stdin=c1.stdout, stdout=sys.stdout, shell=True)
    for _ in range(10):
        time.sleep(2)
        if sys.platform.startswith("linux"):
            os.kill(c1.pid, signal.SIGALRM)
        else:
            os.kill(c1.pid, signal.CTRL_BREAK_EVENT)
    c1.wait()
    c1.stdout.close()
    c2.wait()
    sys.exit()

if __name__ == '__main__':
    main()
